#!/usr/bin/python
from distutils.core import setup
setup(
  name = 'cs.app.megacli',
  description = 'command line tool to inspect and manipulate LSI MegaRAID adapters (such as used in IBM ServerRAID systems)',
  author = 'Cameron Simpson',
  author_email = 'cs@zip.com.au',
  version = '20150801',
  url = 'https://bitbucket.org/cameron_simpson/css/commits/all',
  classifiers = ['Programming Language :: Python', 'Programming Language :: Python :: 2', 'Topic :: Software Development :: Libraries :: Python Modules', 'Operating System :: OS Independent', 'Development Status :: 4 - Beta', 'License :: OSI Approved :: GNU General Public License v3 (GPLv3)', 'Intended Audience :: Developers'],
  entry_points = {'console_scripts': ['mcli = cs.app.megacli:main']},
  keywords = ['python2', 'python3'],
  long_description = u'MegaCLI access kit.\n===================\n\nMany IBM xSeries servers come with LSI Logic MegaRAID RAID controllers, under the name IBM ServerRAID.\n\nThese can be accessed during the machine boot process via the BIOS screens using a conventional BIOS-like text interface or a ghastly and painful to use GUI interface. However, either of these requires the machine OS to be down.\n\nThe RAID adapters can also be accessed while the machine OS is up.\nFor Linux, IBM offer a set of command line tools named MegaCLI_, which are installed in /opt/MegaRAID.\nUnfortunately, their MegaCLI executable is both fiddly to invoke and in its reporting mode, produces a barely human readable report which is quite hostlie to machine parsing.\nI would surmise that someone was told to dump the adapter data in text form, and did so with an ad hoc report; it is pages long and arduous to inspect by eye.\n\nThe situation was sufficiently painful that I wrote this module which runs a couple of the report modes and parses their output. It is deliberately python 2.4 compatible so that it can run on RHEL 5 systems.\n\nThe primary "report" mode then dumps a short summary report of relevant information which can be eyeballed immediately; RAID configuration and issues are immediately apparent. Here is an example output (the "+" tracing lines are on stderr, and recite the underlying MegaCLI commands used)::\n\n  # mcli report\n  + exec py26+ -m cs.app.megacli report\n  + exec /opt/MegaRAID/MegaCli/MegaCli64 -CfgDsply -aAll\n  + exec /opt/MegaRAID/MegaCli/MegaCli64 -PDlist -aAll\n  Adapter 0 IBM ServeRAID-MR10i SAS/SATA Controller serial# Pnnnnnnnnn\n    Virtual Drive 0\n      2 drives, size = 278.464GB, raid = Primary-1, Secondary-0, RAID Level Qualifier-0\n        physical drive enc252.devid8 [252:0]\n        physical drive enc252.devid7 [252:1]\n    4 drives:\n      enc252.devid7 [252:1]: VD 0, DG None: 42D0628 279.396 GB, Online, Spun Up\n      enc252.devid8 [252:0]: VD 0, DG None: 81Y9671 279.396 GB, Online, Spun Up\n      enc252.devid2 [252:2]: VD None, DG None: 42D0628 279.396 GB, Unconfigured(good), Spun Up\n      enc252.devid3 [252:3]: VD None, DG None: 42D0628 279.396 GB, Unconfigured(good), Spun Up\n\nThe secondary "status" mode recites the RAID status in a series of terse one line summaries; we use its output in our nagios monitoring. Here is an example output (the "+" tracing lines are on stderr, and recite the underlying MegaCLI commands used)::\n\n  # mcli status\n  + exec py26+ -m cs.app.megacli status\n  + exec /opt/MegaRAID/MegaCli/MegaCli64 -CfgDsply -aAll\n  + exec /opt/MegaRAID/MegaCli/MegaCli64 -PDlist -aAll\n  OK A0\n\nThe other current mode is "new_raid", which will print a MegaCLI command line which will instruct the adapter to assemble a new RAID set.\n\nMegaCLI class.\n--------------\n\nThe module provides a MegaCLI class which embodies the parsed information from the MegaCLI reporting modes.\nThis can be imported and used for special needs.\n\n.. _MegaCLI: http://www-947.ibm.com/support/entry/portal/docdisplay?lndocid=migr-5082327\n',
  package_dir = {'': 'lib/python'},
  py_modules = ['cs.app.megacli'],
  requires = ['cs.logutils', 'cs.threads', 'cs.obj'],
)
